#
# spec file for package python3-dateutil
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-dateutil
Summary:        A Python Datetime Library
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Version:        2.4.2
Release:        3.2
Source0:        http://pypi.python.org/packages/source/p/python-dateutil/python-dateutil-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            https://dateutil.readthedocs.org/en/latest/
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildArch:      noarch
Requires:       python3-six

%description
The python dateutil module provides powerful extensions to the standard
datetime module.

* Computing of relative deltas (next month, next year, next monday,
   last week of month, etc.)

* Computing of relative deltas between two given dates and/or
   datetime objects

* Computing of dates based on very flexible recurrence rules, using
   a superset of the iCalendar specification. Parsing of RFC strings
   is supported as well.

* Generic parsing of dates in almost any string format.

* Timezone (tzinfo) implementations for tzfile(5) format files
   (/etc/localtime, /usr/share/zoneinfo, etc.), TZ environment
   string (in all known formats), iCalendar format files, given
   ranges (with help from relative deltas), local machine timezone,
   fixed offset timezone, UTC timezone, and Windows registry-based
   time zones.

* Internal up-to-date world timezone information based on Olson's
   database.

* Computing of Easter Sunday dates for any given year, using Western,
Orthodox or Julian algorithms.

%prep
%setup -q -n python-dateutil-%{version}

%build
rm setup.cfg
CFLAGS="%{optflags}" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc LICENSE NEWS PKG-INFO README.rst
%{python3_sitelib}/dateutil/
%{python3_sitelib}/python_dateutil-%{version}-py%{py3_ver}.egg-info/

%changelog
* Wed Apr  8 2015 arun@gmx.de
- specfile:
  * update copyright year
  * removed tarname and modname variable
  * update url
- update to version 2.4.2:
  * Updated zoneinfo to 2015b.
  * Fixed issue with parsing of tzstr on Python 2.7.x; tzstr will now
    be decoded if not a unicode type. gh #51 (lp:1331576), gh pr #55.
  * Fix a parser issue where AM and PM tokens were showing up in fuzzy
    date stamps, triggering inappropriate errors. gh #56 (lp:
    1428895), gh pr #63.
  * Missing function "setcachsize" removed from zoneinfo __all__ list
    by @ryanss, fixing an issue with wildcard imports of
    dateutil.zoneinfo. (gh pr #66).
  * (PyPi only) Fix an issue with source distributions not including
    the test suite.
- changes from version 2.4.1:
  * Added explicit check for valid hours if AM/PM is specified in
    parser. (gh pr #22, issue #21)
  * Fix bug in rrule introduced in 2.4.0 where byweekday parameter was
    not handled properly. (gh pr #35, issue #34)
  * Fix error where parser allowed some invalid dates, overwriting
    existing hours with the last 2-digit number in the string. (gh pr
    [#32], issue #31)
  * Fix and add test for Python 2.x compatibility with boolean
    checking of relativedelta objects. Implemented by @nimasmi (gh pr
    [#43]) and Cédric Krier (lp: 1035038)
  * Replaced parse() calls with explicit datetime objects in unit
    tests unrelated to parser. (gh pr #36)
  * Changed private _byxxx from sets to sorted tuples and fixed one
    currently unreachable bug in _construct_byset. (gh pr #54)
  * Additional documentation for parser (gh pr #29, #33, #41) and
    rrule.
  * Formatting fixes to documentation of rrule and README.rst.
  * Updated zoneinfo to 2015a.
- changes from version 2.4.0:
  * Fix an issue with relativedelta and freezegun (lp:1374022)
  * Fix tzinfo in windows for timezones without dst (lp:1010050, gh
    [#2])
  * Ignore missing timezones in windows like in POSIX
  * Fix minimal version requirement for six (gh #6)
  * Many rrule changes and fixes by @pganssle (gh pull requests #13
    [#14] #17), including defusing some infinite loops (gh #4)
- changes from version 2.3:
  * Cleanup directory structure, moved test.py to
    dateutil/tests/test.py
  * Changed many aspects of dealing with the zone info file. Instead
    of a cache, all the zones are loaded to memory, but symbolic links
    are loaded only once, so not much memory is used.
  * The package is now zip-safe, and universal-wheelable, thanks to
    changes in the handling of the zoneinfo file.
  * Fixed tzwin silently not imported on windows python2
  * New maintainer, together with new hosting: GitHub, Travis,
    Read-The-Docs
* Mon Jan  6 2014 ocefpaf@gmail.com
- Dropped python3-dateutil-utf8.patch.  Fixed in upstream
- Replace python3-distribute with python3-setuptools
- Removed Requires:python(abi) = %%{py3_ver}
- Updated to version 2.2
  - Updated zoneinfo to 2013h
  - fuzzy_with_tokens parse addon from Christopher Corley
  - Bug with LANG=C fixed by Mike Gilbert
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Wed Jun  6 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  Look at the LICENSE file
* Wed Jun  6 2012 toddrme2178@gmail.com
- Added python-six requires and buildrequires.  dateutil will build
  without out, but packaged down the dependency chain will fail
  if it isn't installed
* Sun Jun  3 2012 os-dev@jacraig.com
- Add patch to open file with utf-8 encoding in setup.py
- Remove call to 2to3, dateutil 2.1 supports Python 2.6, 2.7, 3.2
* Wed May 23 2012 highwaystar.ru@gmail.com
- call 2to3 before building, without it result package is
  absolutely broken
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4
* Thu Apr 26 2012 toddrme2178@gmail.com
- Add python 3 package
